@@ -43,7 +43,27 @@ def on_connect(client, userdata, flags, rrc):
 def on_message(client, obj, msg):
     global callback_dit
     topic = msg.topic
-    callback_dit[topic](json.loads(str(msg.payload, encoding="utf-8")), str(client._client_id, encoding='utf-8'))
+    try:
+        callback_dit[topic](json.loads(str(msg.payload, encoding="utf-8")), str(client._client_id, encoding='utf-8'))
+    except Exception as ex:
+        print(ex)
+        keys = callback_dit.keys()
+        topic_arr = topic.split("/")[1:]
+        print(topic_arr)
+        for item in keys:
+            item_arr = item.split("/")[1:]
+            print(item_arr)
+            isThisTopic = True
+            if len(item_arr) == len(topic_arr):
+                for i in range(len(item_arr)):
+                    if item_arr[i] == "+":
+                        continue
+                    if item_arr[i] != topic_arr[i]:
+                        isThisTopic = False
+                        break
+            if isThisTopic:
+                callback_dit[item](json.loads(str(msg.payload, encoding="utf-8")), topic)
+                break
 
 
 def callback():
